#import "HTZViewController.h"

@interface HTZViewController ()
@property (nonatomic, retain) UIWebView *webView;
@end

@implementation HTZViewController
@synthesize webView;

- (void)viewDidLoad
{
    [super viewDidLoad];
	CGFloat width = self.view.bounds.size.width;
    CGFloat height = self.view.bounds.size.height;
    // Create UIToolbar
    UIToolbar *toolBar = [[UIToolbar alloc] initWithFrame:CGRectMake(0, 0, width, 36)];
    toolBar.barStyle = UIBarStyleBlack;
    UILabel *label = [[UILabel alloc] initWithFrame:CGRectMake(0, 0, width, 36)];
    label.text = @"WebViewテンプレート";
    label.textColor = [UIColor whiteColor];
    label.shadowOffset = CGSizeMake(0, -1);
    label.shadowColor = [UIColor grayColor];
    label.backgroundColor = [UIColor clearColor];
    UIBarButtonItem *item = [[UIBarButtonItem alloc] initWithCustomView:label];
    [toolBar setItems:[NSArray arrayWithObjects:item, nil] animated:NO];
    [self.view addSubview:toolBar];
    // Create UIWebView
    self.webView = [[UIWebView alloc] initWithFrame:CGRectMake(0, 36, width, height - 36)];
    self.webView.scalesPageToFit = NO;  // ピンチイン・アウト不可
    self.webView.delegate = self;
    NSString *path = [[NSBundle mainBundle] pathForResource:@"index" ofType:@"html"];
    NSString *html = [NSString stringWithContentsOfFile:path encoding:NSUTF8StringEncoding error:nil];
    NSURL *baseURL = [NSURL fileURLWithPath:[[NSBundle mainBundle] bundlePath]];
    [self.webView loadHTMLString:html baseURL:baseURL];
    [self.view addSubview:self.webView];
    // Disable scroll and bounce（びょ〜んってやつ）
    for(id subview in webView.subviews)
    {
        if([[subview class] isSubclassOfClass:[UIScrollView class]])
        {
            ((UIScrollView *) subview).bounces = NO;
            ((UIScrollView *) subview).scrollEnabled = NO;
        }
    }

}

- (void)viewDidUnload
{
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) 
    {
        // iPhoneなら画面回転させない
        return NO;
    } 
    else 
    {
        return YES;
    }
}

- (BOOL)webView:(UIWebView *)webView shouldStartLoadWithRequest:(NSURLRequest *)request navigationType:(UIWebViewNavigationType)navigationType
{
    NSURL *url = [request URL];
    // native://command?param1=val1&param2=val2を分解する
    if([[url scheme] isEqualToString:@"native"])
    {
        // native:, command?param1=val1&param2=val2
        NSArray *arr1 = [[url absoluteString] componentsSeparatedByString:@"//"];
        // command, param1=val1&param2=val2
        NSArray *arr2 = [[arr1 objectAtIndex:1] componentsSeparatedByString:@"?"];
        NSString *command = [arr2 objectAtIndex:0];
        // param1=val1, param2=val2
        NSArray *params = [[arr2 objectAtIndex:1] componentsSeparatedByString:@"&"];
        if([@"foo" isEqualToString:command])
        {
            NSString *val1 = [[[params objectAtIndex:0] componentsSeparatedByString:@"="] objectAtIndex:1];
            val1 = [val1 stringByReplacingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
            [self.webView stringByEvaluatingJavaScriptFromString:[NSString stringWithFormat:@"iosCallbackFoo('Hello %@ !');", val1]];
            return NO;
        }
        else if([@"hoge" isEqualToString:command])
        {
            NSString *val1 = [[[params objectAtIndex:0] componentsSeparatedByString:@"="] objectAtIndex:1];  // val1
            NSString *val2 = [[[params objectAtIndex:1] componentsSeparatedByString:@"="] objectAtIndex:1];  // val2
            [self httpGet:val1 :val2];
            return NO;  // Cancel loading!
        }
    }
    return YES;
}

- (void)httpGet:(NSString *)val1 :(NSString *)val2
{
    // 日本語GETパラメータの文字化けを防ぐ
    val1 = [val1 stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    val2 = [val2 stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    // URL生成
    NSString *urlStr = [NSString stringWithString:@"http://xxx.xxx.xxx.xxx/xxx?param1="];
    urlStr = [urlStr stringByAppendingString:val1];
    urlStr = [urlStr stringByAppendingString:@"&param2="];
    urlStr = [urlStr stringByAppendingString:val2];
    NSURL *url = [NSURL URLWithString:urlStr];
    // 送信
    NSURLResponse *resp;    // 結果を格納するオブジェクト
    NSError *err;           // エラーを格納するオブジェクト
    NSURLRequest *req = [NSURLRequest requestWithURL:url];
    NSData *data = [NSURLConnection sendSynchronousRequest:req returningResponse:&resp error:&err];
    NSString *errMsg = [err localizedDescription];
    if(0 < [errMsg length])
    {
        [self.webView stringByEvaluatingJavaScriptFromString:[NSString stringWithFormat:@"iosCallbackHttpGetFailed('%@');", errMsg]];
    }
    else 
    {
        NSString *json = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
        // サーバからの結果をJavaScriptへ渡す
        [self.webView stringByEvaluatingJavaScriptFromString:[NSString stringWithFormat:@"iosCallbackHttpGetSucceeded('%@');", json]];
    }
}

@end
